Crate bevy_flair_core

Crate bevy_flair_core 

Bevy Flair Core

Re-exports

pub use property_map::PropertyMap;

Modules

property_map
Contains implementation of a map that has a value for every possible property.

Structs

CanonicalNameNotFoundError
Error when trying to resolve a property that is not registered.
ComponentAutoInserted
Event emitted when a component is inserted automatically into an entity.
ComponentFns
Helper function pointers used to access or modify the value behind a component property.
ComponentPropertiesRegistration
Registration of component properties for a specific component type.
ComponentProperty
Represents a Bevy component property.
ComponentPropertyId
Opaque identifier for a component property.
ComponentPropertyIdHasher
No-op Hasher to be used with ComponentPropertyId.
CssPropertyRegistry
Registry for css property names. It allows to map css property names to component property references.
EntityCommandQueue
Lightweight wrapper over a CommandQueue and a Entity.
ImplComponentPropertiesPlugin
Register all bevy_ui and bevy_text component properties
Iter
An iterator over the entries of a PropertyRegistry.
PropertyCanonicalName
Represents the canonical name of a property inside a component.
PropertyRegistry
Registry for component properties.
PropertyRegistryPlugin
Initializes PropertyRegistry and CssPropertyRegistry in the world.

Enums

ComponentPropertyRef
Reference to a component property. It’s main use is to reference a property when there is no access to the PropertyRegistry. It can be resolved by using PropertyRegistry::resolve.
ComputedValue
Represents a value that have been computed.
CssResolveError
Error when trying to resolve a property that is not registered.
CssResolveResult
Result of resolving a css property name.
PropertyValue
Generic property value that can be used to represent a value that can be inherited, set to a specific value.
ReflectValue
Utility wrapper around a Box<dyn Reflect>: It’s more convenient than using directly Box<dyn Reflect> or an Arc<dyn Reflect> for the following reasons:

Traits

ComponentProperties
Trait for registering component properties in the PropertyRegistry. This trait can be implemented using the impl_component_properties! macro.
ExtractComponentProperties
Trait for extracting component properties from a component type. This trait can be implemented using the impl_extract_component_properties! macro.
ReflectStructPropertyRefExt
Extension trait for getting property references from a struct.
ReflectTupleStructPropertyRefExt
Extension trait for getting property references from a tuple struct.
RegisterComponentPropertiesExt
Extension trait for registering component properties in the PropertyRegistry.

Type Aliases

PropertiesHashMap
A HashMap for ComponentPropertyId as key.
PropertiesHashSet
A HashSet for ComponentPropertyId as key.