Bevy Flair Core
Re-exports
pub use property_map::PropertyMap;
Modules
- property_
map - Contains implementation of a map that has a value for every possible property.
Structs
- Canonical
Name NotFound Error - Error when trying to resolve a property that is not registered.
- Component
Auto Inserted - Event emitted when a component is inserted automatically into an entity.
- Component
Fns - Helper function pointers used to access or modify the value behind a component property.
- Component
Properties Registration - Registration of component properties for a specific component type.
- Component
Property - Represents a Bevy component property.
- Component
Property Id - Opaque identifier for a component property.
- Component
Property IdHasher - No-op Hasher to be used with
ComponentPropertyId. - CssProperty
Registry - Registry for css property names. It allows to map css property names to component property references.
- Entity
Command Queue - Lightweight wrapper over a
CommandQueueand aEntity. - Impl
Component Properties Plugin - Register all bevy_ui and bevy_text component properties
- Iter
- An iterator over the entries of a
PropertyRegistry. - Property
Canonical Name - Represents the canonical name of a property inside a component.
- Property
Registry - Registry for component properties.
- Property
Registry Plugin - Initializes
PropertyRegistryandCssPropertyRegistryin the world.
Enums
- Component
Property Ref - Reference to a component property.
It’s main use is to reference a property when there is no access to the
PropertyRegistry. It can be resolved by usingPropertyRegistry::resolve. - Computed
Value - Represents a value that have been computed.
- CssResolve
Error - Error when trying to resolve a property that is not registered.
- CssResolve
Result - Result of resolving a css property name.
- Property
Value - Generic property value that can be used to represent a value that can be inherited, set to a specific value.
- Reflect
Value - Utility wrapper around a
Box<dyn Reflect>: It’s more convenient than using directlyBox<dyn Reflect>or anArc<dyn Reflect>for the following reasons:
Traits
- Component
Properties - Trait for registering component properties in the
PropertyRegistry. This trait can be implemented using theimpl_component_properties!macro. - Extract
Component Properties - Trait for extracting component properties from a component type.
This trait can be implemented using the
impl_extract_component_properties!macro. - Reflect
Struct Property RefExt - Extension trait for getting property references from a struct.
- Reflect
Tuple Struct Property RefExt - Extension trait for getting property references from a tuple struct.
- Register
Component Properties Ext - Extension trait for registering component properties in the
PropertyRegistry.
Type Aliases
- Properties
Hash Map - A
HashMapforComponentPropertyIdas key. - Properties
Hash Set - A
HashSetforComponentPropertyIdas key.